config_from_ca_cert

Function config_from_ca_cert 

pub fn config_from_ca_cert(
    path: impl AsRef<Path>,
) -> Result<ClientConfig, CaCertError>
Returns a rustls ClientConfig that trusts CA certificates from a PEM file.

This is useful for services such as cloud database providers that publish a CA certificate or bundle for verifying their database servers. Hostname verification is still enabled; the certificates are used only as trust anchors.